@@ -11,9 +11,11 @@ from .stream import GStream
 
 class Kola(kola.Kola):
 
-    def __init__(self, conn_class=None):
-        super(Kola, self).__init__(conn_class or Connection)
+    def __init__(self, server_class=None, conn_class=None):
+        super(Kola, self).__init__()
         self.repeat_timer_func_list = []
+        self.server_class = server_class or StreamServer
+        self.conn_class = conn_class or Connection
 
     def handle_stream(self, sock, address):
         self.conn_class(self, GStream(sock), address).process()
@@ -24,7 +26,7 @@ class Kola(kola.Kola):
             monkey.patch_all()
 
         self._start_repeat_timers()
-        server = StreamServer((host, port), self.handle_stream)
+        server = self.server_class((host, port), self.handle_stream)
         server.serve_forever()
 
     def register_blueprint(self, blueprint):
